

set -ex



test -L $PREFIX/lib/libcufile.so.0
test -L $PREFIX/lib/libcufile.so.1.10.1
test -L $PREFIX/targets/sbsa-linux/lib/libcufile.so.0
test -f $PREFIX/targets/sbsa-linux/lib/libcufile.so.1.10.1
exit 0
